<?php
namespace Ak\Image\Processor\Tinify;

use Interop\Container\ContainerInterface;
use Tinify\Client as TinifyClient;
use Tinify\Tinify;
use Laminas\ServiceManager\Exception\ServiceNotCreatedException;
use Laminas\ServiceManager\Factory\FactoryInterface;

/**
 * Stvara novu instancu klijenta za Tinify API.
 *
 * @package Ak\Image\Processor\Tinify
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/image-processor-tinify
 */
final class TinifyClientFactory implements FactoryInterface
{
    /**
     * Create an object
     *
     * @param  ContainerInterface $container
     * @param  string $requestedName
     * @param  null|array $options
     *
     * @return TinifyClient
     *
     * @throws \Tinify\ClientException
     * @throws \Tinify\ConnectionException
     */
    public function __invoke(ContainerInterface $container, $requestedName, array $options = null)
    {
        $config = $container->get('config')['tinify'] ?? [];
        $apiKey = $config['api_key'] ?? null;

        if (empty($apiKey)) {
            throw new ServiceNotCreatedException(
                "Nedostaje postavka 'api_key'."
            );
        }

        Tinify::setKey($apiKey);
        /** @noinspection PhpUnhandledExceptionInspection */
        return new TinifyClient($apiKey);
    }
}
