<?php
namespace AkTest\Image\Processor\Tinify;

use Ak\Image\Processor\Tinify\TinifyClientFactory;
use Ak\Test\AbstractTestCase;
use ReflectionClass;
use Tinify\Client;

/**
 * Class TinifyClientFactoryTest
 *
 * @package AkTest\Image\Processor\Tinify
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/image-processor-tinify
 */
final class TinifyClientFactoryTest extends AbstractTestCase
{
    public $providers = [
        TestConfigProvider::class,
    ];

    public function testIsRegistered()
    {
        $container = $this->getContainer([
            'tinify' => [
                'api_key' => 'some-api-key',
            ],
        ]);

        $this->assertContainerHasService($container, 'tinify_client', Client::class);
    }

    /**
     * @expectedException \Laminas\ServiceManager\Exception\ServiceNotCreatedException
     */
    public function testWillThrowExceptionIfApiKeyNotSet()
    {
        $container = $this->getContainer();
        $factory = new TinifyClientFactory();

        /** @noinspection PhpUnhandledExceptionInspection */
        $factory($container, '');
    }

    /**
     * @throws \ReflectionException
     * @throws \Tinify\ClientException
     * @throws \Tinify\ConnectionException
     */
    public function testCanCreateTheClient()
    {
        $container = $this->getContainer([
            'tinify' => [
                'api_key' => 'some-api-key',
            ],
        ]);

        $factory = new TinifyClientFactory();
        /** @var Client $client */
        $client = $factory($container, '');

        $this->assertInstanceOf(Client::class, $client);

        $class = new ReflectionClass(Client::class);
        $property = $class->getProperty('options');
        $property->setAccessible(true);

        $options = $property->getValue($client);
        $this->assertEquals('api:some-api-key', $options[CURLOPT_USERPWD]);
    }
}
